function upsilon = lfmvpComputeUpsilonDiagVector(gamma, sigma2, t, mode)

% LFMVPCOMPUTEUPSILONDIAGVECTOR Upsilon diag vector vel. pos. with t1, t2 limits
%
%	Description:
%
%	UPSILON = LFMVPCOMPUTEUPSILONDIAGVECTOR(GAMMA, SIGMA2, T, MODE)
%	computes a portion of the LFMVP kernel.
%	 Returns:
%	  UPSILON - result of this subcomponent of the kernel for the given
%	   values.
%	 Arguments:
%	  GAMMA - Gamma value for system.
%	  SIGMA2 - length scale of latent process.
%	  T - first time input (number of time points x 1).
%	  MODE - operation mode, according to the derivative (mode 0,
%	   derivative wrt t1, mode 1 derivative wrt t2)
%	
%
%	See also
%	LFMCOMPUTEUPSILONMATRIX.F, LFMCOMPUTEH3.M


%	Copyright (c) 2010 Mauricio Alvarez
% 	lfmvpComputeUpsilonDiagVector.m SVN version 807
% 	last update 2010-05-28T06:01:33.000000Z

sigma = sqrt(sigma2);

if mode==0   
    upsilon = -gamma*lfmComputeUpsilonDiagVector(gamma, sigma2, t) ...
        + (2/(sqrt(pi)*sigma));    
else
    upsilon = gamma*lfmComputeUpsilonDiagVector(gamma, sigma2, t) ...
        - (2/(sqrt(pi)*sigma)) ...
        + (2/(sqrt(pi)*sigma))*exp(-gamma*t).*(exp(-(t.^2)/sigma2));
end