function dUpsilonS = lfmvpGradientSigmaUpsilonMatrix(gamma, sigma2, ...
    t1, t2, mode)

% LFMVPGRADIENTSIGMAUPSILONMATRIX Gradient of upsilon matrix vp wrt sigma
%
%	Description:
%
%	UPSILON = LFMVPGRADIENTSIGMAUPSILONMATRIX(GAMMA, SIGMA2, T1, T2,
%	MODE) computes the gradient of a portion of the LFMVP kernel.
%	 Returns:
%	  UPSILON - result of this subcomponent of the kernel for the given
%	   values.
%	 Arguments:
%	  GAMMA - Gamma value for system.
%	  SIGMA2 - length scale of latent process.
%	  T1 - first time input (number of time points x 1).
%	  T2 - second time input (number of time points x 1).
%	  MODE - operation mode, according to the derivative (mode 0,
%	   derivative wrt t1, mode 1 derivative wrt t2)
%	
%
%	See also
%	LFMVPCOMPUTEUPSILONMATRIX.M


%	Copyright (c) 2010 Mauricio A. Alvarez
% 	lfmvpGradientSigmaUpsilonMatrix.m SVN version 807
% 	last update 2011-06-16T07:23:44.000000Z

gridt1 = repmat(t1, 1, length(t2));
gridt2 = repmat(t2', length(t1), 1);
timeGrid = gridt1 - gridt2;

dUpsilon = lfmGradientSigmaUpsilonMatrix(gamma, sigma2, t1, t2);

if mode == 0
    dUpsilonS = -gamma*dUpsilon-(2/(sqrt(pi)*sigma2))*(1-2*(timeGrid.^2)/sigma2).* ...
       exp(-(timeGrid.^2)./sigma2);
else
    dUpsilonS = gamma*dUpsilon+(2/(sqrt(pi)*sigma2))*(1-2*(timeGrid.^2)/sigma2).* ...
       exp(-(timeGrid.^2)./sigma2) - (2/(sqrt(pi)*sigma2))*...
       exp(-gamma*t1)*((1-2*t2.^2/sigma2).*exp(-(t2.^2)/sigma2)).';    
end
